@@ -1,13 +1,13 @@
 # -*- coding: utf-8 -*-
 
-import os
-import unittest
-
+from collective.iconifiedcategory import testing
+from collective.iconifiedcategory.utils import _modified
 from plone import api
 from plone import namedfile
 from plone.app.testing import login
 
-from collective.iconifiedcategory import testing
+import os
+import unittest
 
 
 class BaseTestCase(unittest.TestCase):
@@ -38,6 +38,9 @@ class BaseTestCase(unittest.TestCase):
         f = open(os.path.join(current_path, 'icône1.png'), 'r')
         return namedfile.NamedBlobFile(f.read(), filename=u'icône1.png')
 
+    def _modified(self, obj):
+        return _modified(obj)
+
     def setUp(self):
         self.maxDiff = None
         self.portal = self.layer['portal']
