@@ -211,8 +211,9 @@ def update_all_categorized_elements(container, limited=False, sort=True):
 
 
 def get_ordered_categories_cachekey(method, context, only_enabled=True):
-    """ """
-    return get_cachekey_volatile("collective.iconifiedcategory.utils.get_ordered_categories")
+    """Makes cache depend on config root."""
+    return (repr(get_config_root(context)),
+            get_cachekey_volatile("collective.iconifiedcategory.utils.get_ordered_categories"))
 
 
 @ram.cache(get_ordered_categories_cachekey)
@@ -227,8 +228,8 @@ def get_ordered_categories(context, only_enabled=True):
     if only_enabled:
         query['enabled'] = True
     for idx, category in enumerate(categories):
-        elements[category.UID] = idx
-        elements[calculate_category_id(category.getObject())] = idx
+        elements[category.UID()] = idx
+        elements[calculate_category_id(category)] = idx
         subcategories = find(context=category, unrestricted=True, **query)
         for subcategory in subcategories:
             elements[subcategory.UID] = idx
@@ -496,6 +497,17 @@ def is_file_type(portal_type):
 
 def validateFileIsPDF(data):
     """May be used as helper in a invariant validator"""
+    def _get_content_type(data):
+        """ """
+        contentType = getattr(data, 'contentType', None)
+        if contentType is None:
+            file = request.form.get('form.widgets.file') or \
+                getattr(aq_base(context), 'file', None)
+            # get contentType
+            if file:
+                contentType = getattr(file, 'contentType', None) or file.headers.get('content-type')
+        return contentType
+
     # check if file contentType is PDF only if used content_category requires it
     request = getRequest()
     # avoid double validation
@@ -503,14 +515,11 @@ def validateFileIsPDF(data):
         return
     request.set('already_validateFileIsPDF', True)
     context = data.__context__ or request.get('PUBLISHED').context
-    file = request.form.get('form.widgets.file') or getattr(aq_base(context), 'file', None)
-    # get contentType
-    if file:
-        contentType = getattr(file, 'contentType', None) or file.headers.get('content-type')
-        if contentType != 'application/pdf':
-            category = get_category_object(context, data.content_category)
-            if category.only_pdf:
-                raise Invalid(_(u"You must select a PDF file!"))
+    contentType = _get_content_type(data)
+    if contentType is not None and contentType != 'application/pdf':
+        category = get_category_object(context, data.content_category)
+        if category.only_pdf:
+            raise Invalid(_(u"You must select a PDF file!"))
 
 
 def _modified(obj, asdatetime=True):
